/*      Rexx Program to take a *.zip or *.lzh file, and         */
/*  uncompresses it into a folder with the same root name       */
/*  as the zipped file. Use drag & drop or association.         */
/*  95-07-23  Baden Kudrenecky                                  */
/*      95-08-19 BK Fixed program to use long file and path     */
/*          names as per Doug's (T) request. Also deletes      */
/*          original file after copying it into folder.         */
/*      95-09-10 BK Fixed LZH.  Added missing "/sea" switch     */

unzip_path = 'UNZIP.EXE'
LH32_path = 'LH32.Exe'

call RxFuncAdd 'SysLoadFuncs', 'RexxUtil', 'SysLoadFuncs'
call SysLoadFuncs

path_name = arg(1)
strip_path_name = strip(arg(1), ,'"')
fileroot = left(strip_path_name, lastpos(".", strip_path_name)-1)
file_ext = translate(substr(path_name, lastpos(".",path_name) +1, 2))

if file_ext == 'ZI' | file_ext == 'LZ' then
    do
        rc = SysMkDir(fileroot)
        if rc > 0 then
            do
                call error rc Making_Directory
                exit
            end /* do */
        else
            do
                rc = SysCopyObject(strip_path_name, fileroot)
                if rc == 1 then
                    successful_copy = '1'
                else 
                    call error rc Copy_Zip_file
                fileroot =  '"' || fileroot || '"' 
            end /* do */
    end /* do */
select 
    when file_ext = 'ZI' then
        do
            unzip = unzip_path path_name '-d' fileroot
            unzip
            if rc <> 0 then
                call error rc unzip_zip_file
        end /* do */
    when file_ext = 'LZ' then
        do
            unzip = LH32_path 'x' path_name fileroot "/sea"
            unzip
            if rc <> 0 then
                call error rc unzip_LH32_file
        end /* do */
otherwise
    do
        say ""
        say "       NADA ZIP OR LZH FILE, BOZO!!";
        'pause'
    end /* do */ 
end  /* select */
if successful_copy then 
    rc = SysDestroyObject(strip_path_name)
    if rc <> 1 then
        call error rc Destroy_Compressed_file

exit
/****************************************************************/
error:
    say "   The error code for the procedure was " arg(1) arg(2)
    'pause'
return
